@@ -23,19 +23,29 @@ class WeekdayField(models.CommaSeparatedIntegerField):
     def formfield(self, **kwargs):
         return super(WeekdayField, self).formfield(form_class=WeekdayFormField, **kwargs)
     
-    def to_python(self, value):
-        if isinstance(value, basestring):
-            if value:
-                value = [int(x) for x in value.split(',') if x]
-            else:
-                value = []
-        return value
-
     def get_db_prep_value(self, value, connection=None, prepared=False):
         return ",".join([str(x) for x in value])
+
+def validate_bitwise_notation(data):
+  return data > 0 and data <= (2**7 - 1)
+
+class BitwiseWeekdayField(models.IntegerField):
+    __metaclass__ = models.SubfieldBase
     
+    description = "Bitwise Weekday Field"
+    default_validators = [validate_bitwise_notation]
+
+    def to_python(self, value):
+        if isinstance(value, int):
+          return BitwiseDays(value)
+        return value
+
+    def formfield(self, **kwargs):
+        return super(BitwiseWeekdayField, self).formfield(form_class=BitwiseWeekdayFormField, **kwargs)
+
 try:
     from south.modelsinspector import add_introspection_rules
     add_introspection_rules([], ['^weekday_field\.fields\.WeekdayField'])
+    add_introspection_rules([], ['^weekday_field\.fields\.BitwiseWeekdayField'])
 except ImportError:
-    pass
\ No newline at end of file
+    pass
